#ifndef NT2_INCLUDE_FUNCTIONS_IS_LEZ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_LEZ_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_lez.hpp>

#endif
